mangadap package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mangadap.config
   mangadap.contrib
   mangadap.datacube
   mangadap.par
   mangadap.proc
   mangadap.spectra
   mangadap.survey
   mangadap.util

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.dapfits
   mangadap.version

Module contents
---------------

.. automodule:: mangadap
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
